@@ -5,8 +5,8 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
+ *   copyright (C) 2004-2013                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #include "javacodeoperation.h"
@@ -17,7 +17,7 @@
 #include "uml.h"
 
 JavaCodeOperation::JavaCodeOperation
- (JavaClassifierCodeDocument * doc, UMLOperation *parent, const QString & body, const QString & comment)
+ ( JavaClassifierCodeDocument * doc, UMLOperation *parent, const QString & body, const QString & comment )
         : CodeOperation (doc, parent, body, comment)
 {
     // lets not go with the default comment and instead use
@@ -45,36 +45,36 @@ void JavaCodeOperation::updateMethodDeclaration()
     QString strVis = Uml::Visibility::toString(o->visibility());
     // no return type for constructors
     QString fixedReturn = JavaCodeGenerator::fixTypeName(o->getTypeName());
-    QString returnType = o->isConstructorOperation() ? QString() : (fixedReturn + QLatin1String(" "));
+    QString returnType = o->isConstructorOperation() ? QString("") : (fixedReturn + QString(" "));
     QString methodName = o->name();
-    QString paramStr;
+    QString paramStr = QString("");
 
     // assemble parameters
     UMLAttributeList list = getParentOperation()->getParmList();
     int nrofParam = list.count();
     int paramNum = 0;
-    foreach (UMLAttribute* parm, list) {
+    foreach (UMLAttribute* parm, list ) {
         QString rType = parm->getTypeName();
         QString paramName = parm->name();
-        paramStr += rType + QLatin1Char(' ') + paramName;
+        paramStr += rType + ' ' + paramName;
         paramNum++;
 
-        if (paramNum != nrofParam)
-            paramStr  += QLatin1String(", ");
+        if (paramNum != nrofParam )
+            paramStr  += ", ";
     }
     QString maybeStatic;
     if (o->isStatic())
-        maybeStatic = QLatin1String("static ");
-    QString startText = strVis + QLatin1Char(' ') + maybeStatic + returnType + methodName + QLatin1String(" (") + paramStr + QLatin1Char(')');
+        maybeStatic = "static ";
+    QString startText = strVis + ' ' + maybeStatic + returnType + methodName + " (" + paramStr + ')';
 
     // IF the parent is an interface, our operations look different
     // e.g. they have no body
     if(isInterface) {
-        startText += QLatin1Char(';');
-        setEndMethodText(QString());
+        startText += ';';
+        setEndMethodText("");
     } else {
-        startText += QLatin1String(" {");
-        setEndMethodText(QLatin1String("}"));
+        startText += " {";
+        setEndMethodText("}");
     }
 
     setStartMethodText(startText);
@@ -85,13 +85,13 @@ void JavaCodeOperation::updateMethodDeclaration()
     if(comment.isEmpty() && contentType() == CodeBlock::AutoGenerated)
     {
         UMLAttributeList parameters = o->getParmList();
-        foreach (UMLAttribute* currentAtt, parameters) {
-            comment += endLine + QLatin1String("@param ") + currentAtt->name() + QLatin1Char(' ');
+        foreach (UMLAttribute* currentAtt, parameters ) {
+            comment += endLine + "@param " + currentAtt->name() + ' ';
             comment += currentAtt->doc();
         }
         // add a returns statement too
         if(!returnType.isEmpty())
-            comment += endLine + QLatin1String("@return ") + returnType + QLatin1Char(' ');
+            comment += endLine + "@return " + returnType + ' ';
         getComment()->setText(comment);
     }
 
@@ -114,3 +114,4 @@ int JavaCodeOperation::lastEditableLine()
     return 0;
 }
 
+#include "javacodeoperation.moc"
