@@ -329,7 +329,9 @@ void ClassifierListPage::slotActivateItem(QListWidgetItem* item)
     // there are no items of course;
     //
     // for more information see Qt doc for void QListBox::clearSelection()
-    UMLClassifierListItem* listItem = NULL;
+    UMLClassifierListItemList itemList = getItemList();
+    int itemIndex;
+
     if (item == NULL) {
         if (m_pItemListLB->count() == 0) {
             enableWidgets(false);
@@ -338,18 +340,14 @@ void ClassifierListPage::slotActivateItem(QListWidgetItem* item)
             return;
         }
         m_pItemListLB->setCurrentRow(0);
-        listItem = getItemList().at(0);
+        itemIndex = 0;
     } else {
-        int relativeItemIndex = m_pItemListLB->row(item);
-        if (relativeItemIndex < 0) {
-            uDebug() << "Cannot find item in list.";
-        }
-        else {
-            listItem = getItemList().at( relativeItemIndex );
-        }
+        itemIndex = m_pItemListLB->row(item);
     }
 
-    if (listItem) {
+    if (itemIndex >= 0 && (itemIndex < getItemList().size())) {
+        UMLClassifierListItem* listItem = getItemList().at( itemIndex );
+
         //now update screen
         m_docTE->setText( listItem->doc() );
         if (m_itemType == UMLObject::ot_Operation) {
@@ -358,6 +356,9 @@ void ClassifierListPage::slotActivateItem(QListWidgetItem* item)
         enableWidgets(true);
         m_pOldListItem = listItem;
     }
+    else {
+        uDebug() << "Cannot find item in list.";
+    }
 }
 
 /**
