@@ -4,8 +4,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2006-2014                                                *
- *  Umbrello UML Modeller Authors <umbrello-devel@kde.org>                 *
+ *  copyright (C) 2006-2013                                                *
+ *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
  ***************************************************************************/
 
 // own header
@@ -25,7 +25,6 @@
 #include "actor.h"
 #include "usecase.h"
 #include "component.h"
-#include "port.h"
 #include "node.h"
 #include "artifact.h"
 #include "stereotype.h"
@@ -78,24 +77,14 @@ bool assignUniqueIdOnCreation()
     return (g_predefinedId == Uml::ID::None);
 }
 
-/**
- * Creates a new UMLObject of the given type.
- * No check is made for whether the object named \a name already exists.
- * If the name shall be checked then use @ref createUMLObject.
- *
- * @param type      The type of @ref UMLObject to create.
- * @param name      Name to give to the object (mandatory.)
- * @param parentPkg The object's parent package.
- * @param undoable  Whether to insert the object creation into the undo stack (default: true.)
- */
 UMLObject* createNewUMLObject(UMLObject::ObjectType type, const QString &name,
-                              UMLPackage *parentPkg, bool undoable /* = true */)
+                              UMLPackage *parentPkg)
 {
     if (parentPkg == NULL) {
         uError() << name << ": parentPkg is NULL";
         return NULL;
     }
-    QPointer<UMLObject> o = NULL;
+    UMLObject *o = NULL;
     switch (type) {
         case UMLObject::ot_Actor:
             o = new UMLActor(name, g_predefinedId);
@@ -112,9 +101,6 @@ UMLObject* createNewUMLObject(UMLObject::ObjectType type, const QString &name,
         case UMLObject::ot_Component:
             o = new UMLComponent(name, g_predefinedId);
             break;
-        case UMLObject::ot_Port:
-            o = new UMLPort(name, g_predefinedId);
-            break;
         case UMLObject::ot_Node:
             o = new UMLNode(name, g_predefinedId);
             break;
@@ -149,29 +135,13 @@ UMLObject* createNewUMLObject(UMLObject::ObjectType type, const QString &name,
             uWarning() << "error unknown type: " << UMLObject::toString(type);
             return NULL;
     }
-
-    if (!undoable) {
-        o->setUMLPackage(parentPkg);
-        UMLApp::app()->document()->signalUMLObjectCreated(o);
-        qApp->processEvents();
-        return o;
-    }
-
-    // One user action can result in multiple commands when adding objects via
-    // the toolbar. E.g. "create uml object" and "create widget". Wrap all
-    // commands in one macro. When adding items via list view, this macro will
-    // contain only the "create uml object" command.
-    UMLApp::app()->beginMacro(i18n("Create UML object : %1", name));
-
     o->setUMLPackage(parentPkg);
 
+    // will be caled in cmdCreateUMLObject
+    //parentPkg->addObject(o);
+
     UMLApp::app()->executeCommand(new Uml::CmdCreateUMLObject(o));
-
-    UMLApp::app()->document()->signalUMLObjectCreated(o);
-
     qApp->processEvents();
-
-    UMLApp::app()->endMacro();
     return o;
 }
 
@@ -207,32 +177,18 @@ UMLObject* createUMLObject(UMLObject::ObjectType type, const QString &n,
     }
     if (!n.isEmpty()) {
         UMLObject *o = doc->findUMLObject(n, type, parentPkg);
-        if (o == NULL) {
+        if (o) {
+            if (!solicitNewName)
+                return o;
+        } else {
             o = createNewUMLObject(type, n, parentPkg);
             return o;
         }
-        if (!solicitNewName) {
-            if (type == UMLObject::ot_UMLObject || o->baseType() == type) {
-                uDebug() << o->name() << " already known - returning existing object";
-                return o;
-            }
-            uWarning() << o->name() << " exists but is of type "
-                       << UMLObject::toString(o->baseType())
-                       << " - creating new object of type "
-                       << UMLObject::toString(type);
-            o = createNewUMLObject(type, n, parentPkg, false);
-            return o;
-        }
     }
-
-    bool bValidNameEntered = false;
-    QString name = Model_Utils::uniqObjectName(type, parentPkg, n);
-    if (name == n) {
-        bValidNameEntered = true;
-    }
-
     bool ok = false;
-    while (bValidNameEntered == false) {
+    QString name = Model_Utils::uniqObjectName(type, parentPkg, n);
+    bool bValidNameEntered = false;
+    do {
         name = KInputDialog::getText(i18nc("UMLObject name", "Name"), i18n("Enter name:"), name, &ok, (QWidget*)UMLApp::app());
         if (!ok) {
             return 0;
@@ -254,8 +210,7 @@ UMLObject* createUMLObject(UMLObject::ObjectType type, const QString &n,
             continue;
         }
         bValidNameEntered = true;
-    }
-
+    } while (bValidNameEntered == false);
     UMLObject *o = createNewUMLObject(type, name, parentPkg);
     return o;
 }
@@ -282,63 +237,62 @@ UMLOperation *createOperation(UMLClassifier *parent, const QString& name)
  *
  * @param parent    The parent concept
  * @param type      The type to create
- * @param name      Optional name of object (skips creation dialog)
  * @return      Pointer to the UMLClassifierListItem created
  */
-UMLClassifierListItem* createChildObject(UMLClassifier* parent, UMLObject::ObjectType type, const QString& name)
+UMLClassifierListItem* createChildObject(UMLClassifier* parent, UMLObject::ObjectType type)
 {
     UMLObject* returnObject = NULL;
     switch (type) {
     case UMLObject::ot_Attribute: {
         UMLClassifier *c = dynamic_cast<UMLClassifier*>(parent);
             if (c && !c->isInterface())
-                returnObject = c->createAttribute(name);
+                returnObject = c->createAttribute();
             break;
         }
     case UMLObject::ot_EntityAttribute: {
-         UMLEntity *e = dynamic_cast<UMLEntity*>(parent);
-         if (e) {
-             returnObject = e->createAttribute(name);
+         UMLEntity *e = dynamic_cast<UMLEntity*>( parent );
+         if ( e ) {
+             returnObject = e->createAttribute();
          }
          break;
         }
     case UMLObject::ot_Operation: {
             UMLClassifier *c = dynamic_cast<UMLClassifier*>(parent);
             if (c)
-                returnObject = c->createOperation(name);
+                returnObject = c->createOperation();
             break;
         }
     case UMLObject::ot_Template: {
             UMLClassifier *c = dynamic_cast<UMLClassifier*>(parent);
             if (c)
-                returnObject = c->createTemplate(name);
+                returnObject = c->createTemplate();
             break;
         }
     case UMLObject::ot_EnumLiteral: {
             UMLEnum* umlenum = dynamic_cast<UMLEnum*>(parent);
             if (umlenum) {
-                returnObject = umlenum->createEnumLiteral(name);
+                returnObject = umlenum->createEnumLiteral();
             }
             break;
         }
     case UMLObject::ot_UniqueConstraint: {
-            UMLEntity* umlentity = dynamic_cast<UMLEntity*>(parent);
-            if (umlentity) {
-                returnObject = umlentity->createUniqueConstraint(name);
+            UMLEntity* umlentity = dynamic_cast<UMLEntity*>( parent );
+            if ( umlentity ) {
+                returnObject = umlentity->createUniqueConstraint();
             }
             break;
         }
     case UMLObject::ot_ForeignKeyConstraint: {
-            UMLEntity* umlentity = dynamic_cast<UMLEntity*>(parent);
-            if (umlentity) {
-                returnObject = umlentity->createForeignKeyConstraint(name);
+            UMLEntity* umlentity = dynamic_cast<UMLEntity*>( parent );
+            if ( umlentity ) {
+                returnObject = umlentity->createForeignKeyConstraint();
             }
             break;
         }
     case UMLObject::ot_CheckConstraint: {
-            UMLEntity* umlentity = dynamic_cast<UMLEntity*>(parent);
-            if (umlentity) {
-                returnObject = umlentity->createCheckConstraint(name);
+            UMLEntity* umlentity = dynamic_cast<UMLEntity*>( parent );
+            if ( umlentity ) {
+                returnObject = umlentity->createCheckConstraint();
             }
             break;
         }
@@ -356,65 +310,58 @@ UMLObject* makeObjectFromXMI(const QString& xmiTag,
                              const QString& stereoID /* = QString() */)
 {
     UMLObject* pObject = 0;
-    if (UMLDoc::tagEq(xmiTag, QLatin1String("UseCase"))) {
+    if (UMLDoc::tagEq(xmiTag, "UseCase")) {
         pObject = new UMLUseCase();
-    } else if (UMLDoc::tagEq(xmiTag, QLatin1String("Actor"))) {
+    } else if (UMLDoc::tagEq(xmiTag, "Actor")) {
         pObject = new UMLActor();
-    } else if (UMLDoc::tagEq(xmiTag, QLatin1String("Class"))) {
+    } else if (UMLDoc::tagEq(xmiTag, "Class")) {
         pObject = new UMLClassifier();
-    } else if (UMLDoc::tagEq(xmiTag, QLatin1String("Package"))) {
+    } else if (UMLDoc::tagEq(xmiTag, "Package")) {
         if (!stereoID.isEmpty()) {
             UMLDoc *doc = UMLApp::app()->document();
             UMLObject *stereo = doc->findStereotypeById(Uml::ID::fromString(stereoID));
-            if (stereo && stereo->name() == QLatin1String("folder"))
+            if (stereo && stereo->name() == "folder")
                 pObject = new UMLFolder();
         }
         if (pObject == NULL)
             pObject = new UMLPackage();
-    } else if (UMLDoc::tagEq(xmiTag, QLatin1String("Component"))) {
+    } else if (UMLDoc::tagEq(xmiTag, "Component")) {
         pObject = new UMLComponent();
-    } else if (UMLDoc::tagEq(xmiTag, QLatin1String("Port"))) {
-        pObject = new UMLPort();
-    } else if (UMLDoc::tagEq(xmiTag, QLatin1String("Node"))) {
+    } else if (UMLDoc::tagEq(xmiTag, "Node")) {
         pObject = new UMLNode();
-    } else if (UMLDoc::tagEq(xmiTag, QLatin1String("Artifact"))) {
+    } else if (UMLDoc::tagEq(xmiTag, "Artifact")) {
         pObject = new UMLArtifact();
-    } else if (UMLDoc::tagEq(xmiTag, QLatin1String("Interface"))) {
+    } else if (UMLDoc::tagEq(xmiTag, "Interface")) {
         UMLClassifier *c = new UMLClassifier();
         c->setBaseType(UMLObject::ot_Interface);
         pObject = c;
-    } else if (UMLDoc::tagEq(xmiTag, QLatin1String("DataType"))
-            || UMLDoc::tagEq(xmiTag, QLatin1String("Datatype"))   // for bkwd compat.
-            || UMLDoc::tagEq(xmiTag, QLatin1String("Primitive"))
-            || UMLDoc::tagEq(xmiTag, QLatin1String("PrimitiveType"))) {
+    } else if (UMLDoc::tagEq(xmiTag, "DataType") || UMLDoc::tagEq(xmiTag, "Primitive")
+               || UMLDoc::tagEq(xmiTag, "Datatype")) {   // for bkwd compat.
         UMLClassifier *c = new UMLClassifier();
         c->setBaseType(UMLObject::ot_Datatype);
         pObject = c;
-    } else if (UMLDoc::tagEq(xmiTag, QLatin1String("Enumeration")) ||
-               UMLDoc::tagEq(xmiTag, QLatin1String("Enum"))) {   // for bkwd compat.
+    } else if (UMLDoc::tagEq(xmiTag, "Enumeration") ||
+               UMLDoc::tagEq(xmiTag, "Enum")) {   // for bkwd compat.
         pObject = new UMLEnum();
-    } else if (UMLDoc::tagEq(xmiTag, QLatin1String("Entity"))) {
+    } else if (UMLDoc::tagEq(xmiTag, "Entity")) {
         pObject = new UMLEntity();
-    } else if (UMLDoc::tagEq(xmiTag, QLatin1String("Category"))) {
+    } else if (UMLDoc::tagEq(xmiTag, "Category")) {
         pObject = new UMLCategory();
-    } else if (UMLDoc::tagEq(xmiTag, QLatin1String("Stereotype"))) {
+    } else if (UMLDoc::tagEq(xmiTag, "Stereotype")) {
         pObject = new UMLStereotype();
-    } else if (UMLDoc::tagEq(xmiTag, QLatin1String("Association")) ||
-               UMLDoc::tagEq(xmiTag, QLatin1String("AssociationClass"))) {
+    } else if (UMLDoc::tagEq(xmiTag, "Association") ||
+               UMLDoc::tagEq(xmiTag, "AssociationClass")) {
         pObject = new UMLAssociation();
-    } else if (UMLDoc::tagEq(xmiTag, QLatin1String("Generalization")) ||
-               UMLDoc::tagEq(xmiTag, QLatin1String("generalization"))) {
+    } else if (UMLDoc::tagEq(xmiTag, "Generalization")) {
         pObject = new UMLAssociation(Uml::AssociationType::Generalization);
-    } else if (UMLDoc::tagEq(xmiTag, QLatin1String("Realization")) ||
-               UMLDoc::tagEq(xmiTag, QLatin1String("Abstraction"))) {
+    } else if (UMLDoc::tagEq(xmiTag, "Realization") ||
+               UMLDoc::tagEq(xmiTag, "Abstraction")) {
         pObject = new UMLAssociation(Uml::AssociationType::Realization);
-    } else if (UMLDoc::tagEq(xmiTag, QLatin1String("Dependency"))) {
+    } else if (UMLDoc::tagEq(xmiTag, "Dependency")) {
         pObject = new UMLAssociation(Uml::AssociationType::Dependency);
-    } else if (UMLDoc::tagEq(xmiTag, QLatin1String("Aggregation"))) {  // Embarcadero's Describe
-        pObject = new UMLAssociation(Uml::AssociationType::Aggregation);
-    } else if (UMLDoc::tagEq(xmiTag, QLatin1String("Child2Category"))) {
+    } else if (UMLDoc::tagEq(xmiTag, "Child2Category")) {
         pObject = new UMLAssociation(Uml::AssociationType::Child2Category);
-    } else if (UMLDoc::tagEq(xmiTag, QLatin1String("Category2Parent"))) {
+    } else if (UMLDoc::tagEq(xmiTag, "Category2Parent")) {
         pObject = new UMLAssociation(Uml::AssociationType::Category2Parent);
     }
 
