@@ -4,8 +4,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
+ *   copyright (C) 2003-2013                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
@@ -17,15 +17,9 @@
 #include "uml.h"
 
 // kde includes
-#if QT_VERSION < 0x050000
+#include <klocale.h>
 #include <kinputdialog.h>
-#endif
-#include <KLocalizedString>
 
-// qt includes
-#if QT_VERSION >= 0x050000
-#include <QInputDialog>
-#endif
 
 /**
  * Sets up a stereotype.
@@ -34,12 +28,13 @@
  * @param id     The unique id given to this UMLStereotype.
  */
 UMLStereotype::UMLStereotype(const QString &name, Uml::ID::Type id /* = Uml::id_None */)
-  : UMLObject(name, id)
+  : UMLObject( name, id )
 {
     m_BaseType = UMLObject::ot_Stereotype;
     UMLStereotype * existing = UMLApp::app()->document()->findStereotype(name);
     if (existing) {
-        uError() << "UMLStereotype constructor: " << name << " already exists";
+        uError() << "UMLStereotype constructor: " << name << " already exists"
+                  << kBacktrace(25);
     }
     m_refCount = 0;
 }
@@ -64,13 +59,13 @@ UMLStereotype::~UMLStereotype()
 /**
  * Overloaded '==' operator.
  */
-bool UMLStereotype::operator==(const UMLStereotype &rhs) const
+bool UMLStereotype::operator==( const UMLStereotype &rhs) const
 {
     if (this == &rhs) {
         return true;
     }
 
-    if (!UMLObject::operator==(rhs)) {
+    if ( !UMLObject::operator==( rhs ) ) {
         return false;
     }
 
@@ -103,8 +98,8 @@ UMLObject* UMLStereotype::clone() const
 void UMLStereotype::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
 {
     //FIXME: uml13.dtd compliance
-    QDomElement stereotypeElement = UMLObject::save(QLatin1String("UML:Stereotype"), qDoc);
-    qElement.appendChild(stereotypeElement);
+    QDomElement stereotypeElement = UMLObject::save("UML:Stereotype", qDoc);
+    qElement.appendChild( stereotypeElement );
 }
 
 /**
@@ -114,14 +109,7 @@ void UMLStereotype::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
 bool UMLStereotype::showPropertiesDialog(QWidget* parent)
 {
     bool ok;
-#if QT_VERSION >= 0x050000
-    QString stereoTypeName = QInputDialog::getText(parent,
-                                                   i18n("Stereotype"), i18n("Enter name:"),
-                                                   QLineEdit::Normal,
-                                                   name(), &ok);
-#else
     QString stereoTypeName = KInputDialog::getText(i18n("Stereotype"), i18n("Enter name:"), name(), &ok, parent);
-#endif
     if (ok) {
         setName(stereoTypeName);
     }
@@ -152,13 +140,3 @@ int UMLStereotype::refCount() const
     return m_refCount;
 }
 
-/**
- * Returns the name as string
- */
-QString UMLStereotype::name(bool includeAdornments) const
-{
-    if (includeAdornments)
-        return QString::fromUtf8("«") + UMLObject::name() + QString::fromUtf8("»");
-    else
-        return UMLObject::name();
-}
