@@ -4,43 +4,31 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
+ *   copyright (C) 2002-2013                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #ifndef UML_H
 #define UML_H
 
 #include "basictypes.h"
-#include "multipagedialogbase.h"
 
-// kde includes
 #include <kxmlguiwindow.h>
-#if QT_VERSION < 0x050000
 #include <kurl.h>
-#endif
 #include <ksharedconfig.h>
 
-// qt includes
-#if QT_VERSION >= 0x050000
-#include <QUrl>
-#endif
-
 // forward declaration of the UML classes
-class BirdView;
-class BirdViewDockWidget;
 class CodeDocument;
 class CodeGenerator;
 class CodeGenerationPolicy;
 class CodeGenPolicyExt;
 class DocWindow;
-class UMLAppPrivate;
 class UMLClassifier;
 class UMLDoc;
 class UMLListView;
 class UMLView;
 class WorkToolBar;
-class SettingsDialog;
+class SettingsDlg;
 class UMLViewImageExporterAll;
 class RefactoringAssistant;
 class XhtmlGenerator;
@@ -53,28 +41,23 @@ class KRecentFilesAction;
 class KToggleAction;
 class KTabWidget;
 class KMenu;
-#if QT_VERSION < 0x050000
+class KMenuBar;
 class KUndoStack;
-#endif
 class KAction;
 
 // Qt forward declarations
 class QStackedWidget;
 class QToolButton;
+class QCustomEvent;
 class QDockWidget;
 class QVBoxLayout;
 class QKeyEvent;
 class QMenu;
 class QMimeData;
-class QPrinter;
 class QUndoCommand;
 class QUndoView;
-#if QT_VERSION >= 0x050000
-class QUndoStack;
-#endif
 class QPushButton;
 class QLabel;
-class QListWidget;
 class QSlider;
 
 /**
@@ -93,7 +76,7 @@ class QSlider;
  * @see KConfig
  *
  * @author Paul Hensgen <phensgen@techie.com>
- * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
+ * Bugs and comments to uml-devel@lists.sf.net or http://bugs.kde.org
  */
 class UMLApp : public KXmlGuiWindow
 {
@@ -104,11 +87,7 @@ public:
 
     static UMLApp* app();
 
-#if QT_VERSION >= 0x050000
-    void openDocumentFile(const QUrl& url=QUrl());
-#else
     void openDocumentFile(const KUrl& url=KUrl());
-#endif
 
     void newDocument();
 
@@ -117,26 +96,18 @@ public:
     UMLListView* listView() const;
     WorkToolBar* workToolBar() const;
     DocWindow * docWindow() const;
-    QListWidget *logWindow() const;
-
-    QCursor defaultCursor();
 
     void setModified(bool _m);
 
     void enablePrint(bool enable);
+    void enableUndo(bool enable);
+    void enableRedo(bool enable);
 
+    bool isUndoEnabled() const;
+    bool isRedoEnabled() const;
     bool isPasteState() const;
     bool isCutCopyState() const;
 
-    bool isUndoEnabled();
-    void enableUndo(bool enable);
-
-    bool isUndoActionEnabled() const;
-    void enableUndoAction(bool enable);
-
-    bool isRedoActionEnabled() const;
-    void enableRedoAction(bool enable);
-
     bool isSimpleCodeGeneratorActive();
 
     void setGenerator(CodeGenerator* gen, bool giveWarning = true);
@@ -154,7 +125,7 @@ public:
 
     QWidget* mainViewWidget();
 
-    void setCurrentView(UMLView* view, bool updateTreeView = true);
+    void setCurrentView(UMLView* view);
     UMLView* currentView() const;
 
     void setImageMimeType(const QString& mimeType);
@@ -162,11 +133,7 @@ public:
 
     bool editCutCopy(bool bFromView);
 
-#if QT_VERSION >= 0x050000
-    QTabWidget *tabWidget();
-#else
     KTabWidget *tabWidget();
-#endif
 
     QString statusBarMsg();
 
@@ -194,7 +161,6 @@ public:
     QString activeLanguageScopeSeparator();
 
     KConfig* config();
-    void importFiles(QStringList* fileList);
 
 protected:
     virtual void keyPressEvent(QKeyEvent* e);
@@ -212,6 +178,7 @@ protected:
     void initView();
 
     virtual bool queryClose();
+    virtual bool queryExit();
 
     virtual void saveProperties(KConfigGroup & cfg);
     virtual void readProperties(const KConfigGroup & cfg);
@@ -224,12 +191,7 @@ public slots:
 
     void slotFileNew();
     void slotFileOpen();
-
-#if QT_VERSION >= 0x050000
-    void slotFileOpenRecent(const QUrl& url);
-#else
     void slotFileOpenRecent(const KUrl& url);
-#endif
     void slotFileSave();
     bool slotFileSaveAs();
     void slotFileClose();
@@ -240,9 +202,6 @@ public slots:
     void slotFileQuit();
     void slotFileExportDocbook();
     void slotFileExportXhtml();
-    void slotFind();
-    void slotFindNext();
-    void slotFindPrevious();
     void slotEditCut();
     void slotEditCopy();
     void slotEditPaste();
@@ -266,23 +225,18 @@ public slots:
     void slotAlignHorizontalDistribute();
     void slotClipDataChanged();
     void slotCopyChanged();
-    void slotPrefs(MultiPageDialogBase::PageType page = MultiPageDialogBase::GeneralPage);
+    void slotPrefs();
     void slotApplyPrefs();
-    void slotImportClass();
-    void slotImportProject();
     void slotUpdateViews();
     void slotShowTreeView(bool state);
-    void slotShowDebugView(bool state);
     void slotShowDocumentationView(bool state);
     void slotShowCmdHistoryView(bool state);
-    void slotShowLogView(bool state);
-    void slotShowBirdView(bool state);
     void slotCurrentViewClearDiagram();
     void slotCurrentViewToggleSnapToGrid();
     void slotCurrentViewToggleShowGrid();
     void slotCurrentViewExportImage();
     void slotAllViewsExportImage();
-    void slotCurrentProperties();
+    void slotCurrentViewProperties();
     void slotClassWizard();
     void slotAddDefaultDatatypes();
     void slotCurrentViewChanged();
@@ -291,11 +245,7 @@ public slots:
     void slotSelectAll();
     void slotDeleteSelected();
     void slotDeleteDiagram();
-#if QT_VERSION >= 0x050000
-    void slotCloseDiagram(int index);
-#else
     void slotCloseDiagram(QWidget* tab);
-#endif
     void slotGenerateAllCode();
 
     void slotSetZoom(QAction* action);
@@ -305,18 +255,12 @@ public slots:
     void slotZoomOut();
     void slotZoomIn();
 
-    void slotBirdViewChanged(const QPoint& delta);
-
     void setupZoomMenu();
 
     void slotEditUndo();
     void slotEditRedo();
 
-#if QT_VERSION >= 0x050000
-    void slotTabChanged(int index);
-#else
     void slotTabChanged(QWidget* tab);
-#endif
     void slotChangeTabLeft();
     void slotChangeTabRight();
     void slotMoveTabLeft();
@@ -345,13 +289,9 @@ private slots:
     void setLang_tcl();
     void setLang_vala();
     void setLang_xmlschema();
-#if QT_VERSION >= 0x050000
-    void slotDiagramPopupMenu(const QPoint& point);
-#endif
 
 private:
     static UMLApp* s_instance;  ///< The last created instance of this class.
-    UMLAppPrivate *m_d;
 
     QMenu* findMenu(const QString &name);
 
@@ -360,7 +300,7 @@ private:
 
     void resetStatusMsg();
 
-    void setProgLangAction(Uml::ProgrammingLanguage::Enum pl, const char* name, const char* action);
+    void setProgLangAction(Uml::ProgrammingLanguage::Enum pl, const QString& name, const QString& action);
 
     static bool canDecode(const QMimeData* mimeSource);
 
@@ -369,9 +309,9 @@ private:
     void initClip();
     void initSavedCodeGenerators();
 
-    void createDiagram(Uml::DiagramType::Enum type);
+    void importFiles(QStringList* fileList);
 
-    void createBirdView(UMLView* view);
+    void createDiagram(Uml::DiagramType::Enum type);
 
     QMenu* m_langSelect;  ///< For selecting the active language.
     QMenu* m_zoomSelect;  ///< Popup menu for zoom selection.
@@ -380,7 +320,7 @@ private:
     CodeGenerator*            m_codegen;         ///< Active code generator.
     CodeGenerationPolicy*     m_commoncodegenpolicy;
     CodeGenPolicyExt*         m_policyext;       ///< Active policy extension.
-    // Only used for new code generators ({Cpp, Java, Ruby, D}CodeGenerator).
+    // Only used for new code generators ({Cpp,Java,Ruby,D}CodeGenerator).
 
     KSharedConfigPtr m_config;  ///< The configuration object of the application.
 
@@ -403,16 +343,11 @@ private:
 
     QDockWidget* m_mainDock;           ///< The widget which shows the diagrams.
     QDockWidget* m_listDock;           ///< Contains the UMLListView tree view.
-    QDockWidget* m_debugDock;          ///< Contains the debug DocWindow widget.
     QDockWidget* m_documentationDock;  ///< Contains the documentation DocWindow widget.
     QDockWidget* m_cmdHistoryDock;     ///< Contains the undo/redo viewer widget.
     QDockWidget* m_propertyDock;       ///< Contains the property browser widget.
-    QDockWidget* m_logDock;            ///< Contains the log window widget.
-    BirdViewDockWidget* m_birdViewDock;///< Contains the bird's eye view
 
-    DocWindow*   m_docWindow;          ///< Documentation window.
-    QListWidget* m_logWindow;          ///< Logging window.
-    BirdView*    m_birdView;           ///< Bird View window
+    DocWindow*   m_docWindow;         ///< Documentation window.
     QUndoView*   m_pQUndoView;         ///< Undo / Redo Viewer
     RefactoringAssistant* m_refactoringAssist;  ///< Refactoring assistant.
 
@@ -427,11 +362,8 @@ private:
     QAction* editRedo;
 
     QAction* viewShowTree;
-    QAction* viewShowDebug;
     QAction* viewShowDoc;
-    QAction* viewShowLog;
     QAction* viewShowCmdHistory;
-    QAction* viewShowBirdView;
 
     KActionMenu* newDiagram;
     QAction* viewClearDiagram;
@@ -444,13 +376,9 @@ private:
     QAction* zoom100Action;
 
     QAction* m_langAct[Uml::ProgrammingLanguage::Reserved];
-#if QT_VERSION >= 0x050000
-    QAction* deleteSelectedWidget;
-    QAction* deleteDiagram;
-#else
     KAction* deleteSelectedWidget;
     KAction* deleteDiagram;
-#endif
+
     QToolButton* m_newSessionButton;
     KMenu* m_diagramMenu;
     WorkToolBar* m_toolsbar;
@@ -469,11 +397,7 @@ private:
      * Shows, and is parent of, all the UMLViews (diagrams)
      * if tabbed diagrams are enabled.
      */
-#if QT_VERSION >= 0x050000
-    QTabWidget* m_tabWidget;
-#else
     KTabWidget* m_tabWidget;
-#endif
 
     /**
      * Layout supports the dynamic management of the diagram representation (tabbed/stacked)
@@ -484,7 +408,7 @@ private:
 
     QString m_imageMimeType;  ///< Default mime type to use for image export.
 
-    SettingsDialog* m_settingsDialog;  ///< The global UML settings dialog.
+    SettingsDlg* m_settingsDlg;  ///< The global UML settings dialog.
 
     UMLViewImageExporterAll* m_imageExporterAll;  ///< Used to export all the views.
 
@@ -503,12 +427,7 @@ private:
      */
     XhtmlGenerator* m_xhtmlGenerator;
 
-#if QT_VERSION >= 0x050000
-    QUndoStack* m_pUndoStack;  ///< UndoStack used to store actions, to provide Undo/Redo feature.
-#else
     KUndoStack* m_pUndoStack;  ///< UndoStack used to store actions, to provide Undo/Redo feature.
-#endif
-    bool m_undoEnabled; ///< Undo enabled flag
 
     bool m_hasBegunMacro;  ///< Macro creation flag.
 
