@@ -645,8 +645,6 @@ bool UMLWidget::activate(IDChangeLog* /*ChangeLog  = 0 */)
         UMLScenePoint point = m_scene->getPastePoint();
         int x = point.x() + this->x();
         int y = point.y() + this->y();
-        x = x < 0 ? 0 : x;
-        y = y < 0 ? 0 : y;
         if (m_scene->type() == Uml::DiagramType::Sequence) {
             switch (baseType()) {
             case WidgetBase::wt_Object:
